pub(crate) fn entry_global() -> DomRoot<GlobalScope>Expand description
Returns the “entry” global object. Panics if there is no valid entry object on the stack.
pub(crate) fn entry_global() -> DomRoot<GlobalScope>Returns the “entry” global object. Panics if there is no valid entry object on the stack.